// Copyright (C) 2015 The Android Open Source Project
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package com.google.gerrit.server.query.change;

import com.google.gerrit.reviewdb.client.Branch;
import com.google.gerrit.reviewdb.client.Change;
import com.google.gwtorm.server.OrmException;
import java.util.Set;

class DestinationPredicate extends ChangeOperatorPredicate {
  Set<Branch.NameKey> destinations;

  DestinationPredicate(Set<Branch.NameKey> destinations, String value) {
    super(ChangeQueryBuilder.FIELD_DESTINATION, value);
    this.destinations = destinations;
  }

  @Override
  public boolean match(final ChangeData object) throws OrmException {
    Change change = object.change();
    if (change == null) {
      return false;
    }
    return destinations.contains(change.getDest());
  }

  @Override
  public int getCost() {
    return 1;
  }
}
